@@ -6,6 +6,7 @@ export NN_CXX_ORIG=$CXX
 export NN_CC_ORIG=$CC
 export CXX=$RECIPE_DIR/cxx_wrap.sh
 export CC=$RECIPE_DIR/cc_wrap.sh
+export CMAKE_OSX_DEPLOYMENT_TARGET=${MACOSX_DEPLOYMENT_TARGET}
 
 if [[ $target_platform =~ osx-arm64 ]]; then
   CURL_LIBS_APPEND=`$PREFIX/bin/curl-config --libs`
@@ -29,6 +30,7 @@ cmake ${CMAKE_ARGS} \
   -DTILEDB_SERIALIZATION=ON \
   -DTILEDB_LOG_OUTPUT_ON_FAILURE=ON \
   -DTILEDB_AZURE=ON \
+  -DCMAKE_OSX_DEPLOYMENT_TARGET=${MACOSX_DEPLOYMENT_TARGET} \
   ..
 make -j ${CPU_COUNT}
 make -C tiledb install
